@@ -324,7 +324,10 @@ class EventDescriptor:
         When not specified, the engine will inspect the module implementation and find all datatypes supported
         as payload in the functions defined as `__steps__`. In case of generic functions that support
         `payload: DataObject` argument, then a list of full qualified datatypes must be specified here.
+    :field: group, str: group name, if none is assigned it is automatically assigned as 'DEFAULT'.
     """
+    DEFAULT_GROUP = 'DEFAULT'
+
     type: EventType
     plug_mode: EventPlugMode = EventPlugMode.STANDALONE
     route: Optional[str] = None
@@ -335,6 +338,7 @@ class EventDescriptor:
     auth: List[AuthType] = field(default_factory=list)
     setting_keys: List[str] = field(default_factory=list)
     dataobjects: List[str] = field(default_factory=list)
+    group: str = DEFAULT_GROUP
 
     def __post_init__(self):
         if self.read_stream:
